==> libvoikko_2.2.2.orig.tar.gz: libvoikko-2.2.2/src/spellchecker/suggestion/SuggestionStrategy.hpp <==
/* Libvoikko: Finnish spellchecker and hyphenator library
 * Copyright (C) 2009 Harri Pitkänen <hatapitk@iki.fi>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *********************************************************************************/

#ifndef VOIKKO_SPELLCHECKER_SUGGESTION_SUGGESTION_STRATEGY_H
#define VOIKKO_SPELLCHECKER_SUGGESTION_SUGGESTION_STRATEGY_H

#include "spellchecker/suggestion/SuggestionGenerator.hpp"
#include "spellchecker/suggestion/SuggestionStatus.hpp"
#include <list>

namespace libvoikko { namespace spellchecker { namespace suggestion {

class SuggestionStrategy : public SuggestionGenerator {
	public:
		SuggestionStrategy();
		~SuggestionStrategy();
		void generate(SuggestionStatus * s) const;

	protected:
		SuggestionStrategy(SuggestionStrategy const & other);
		SuggestionStrategy & operator = (const SuggestionStrategy & other);
		std::list<SuggestionGenerator *> generators;

};

}}}

#endif

==> libvoikko_3.0.orig.tar.gz: libvoikko-3.0/src/spellchecker/suggestion/SuggestionStrategy.hpp <==
/* Libvoikko: Finnish spellchecker and hyphenator library
 * Copyright (C) 2009 - 2010 Harri Pitkänen <hatapitk@iki.fi>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *********************************************************************************/

#ifndef VOIKKO_SPELLCHECKER_SUGGESTION_SUGGESTION_STRATEGY_H
#define VOIKKO_SPELLCHECKER_SUGGESTION_SUGGESTION_STRATEGY_H

#include "spellchecker/suggestion/SuggestionGenerator.hpp"
#include "spellchecker/suggestion/SuggestionStatus.hpp"
#include <list>

namespace libvoikko { namespace spellchecker { namespace suggestion {

class SuggestionStrategy : public SuggestionGenerator {
	public:
		SuggestionStrategy(size_t maxCost);
		~SuggestionStrategy();
		void generate(SuggestionStatus * s) const;

	protected:
		SuggestionStrategy(SuggestionStrategy const & other);
		SuggestionStrategy & operator = (const SuggestionStrategy & other);

		/** These generators are run first. If any suggestions are found,
		 *  running normal generators is skipped.
		 */
		std::list<SuggestionGenerator *> primaryGenerators;

		/** Normal generators, run if primaryGenerators have not returned
		 *  any suggestions.
		 */
		std::list<SuggestionGenerator *> generators;

	private:
		const size_t maxCost;
};

}}}

#endif
